---
title: Release Iamport-cordova v0.9.9
category: 업데이트
tags:
  - 업데이트
datetime: 2021-10-28T15:00:00.000Z
---

안녕하세요. 포트원 기술지원팀 입니다.

포트원 코르도바 v0.9.9 가 배포되었습니다.

- iOS15 에서 문제가 되었던 navigation bar 투명 이슈를 수정하였습니다.
- 내장된 포트원 JS SDK 가 1.2.0 으로 업데이트 되었습니다.자세한 내용 및 반영사항은 아래 링크 참고 부탁 드립니다.

자세한 내용 및 반영사항은 아래 링크 참고 부탁 드립니다.

- [github 보러가기 ↗](https://github.com/iamport/iamport-cordova)
- [버전정보 보러가기 ↗](https://github.com/iamport/iamport-cordova/blob/master/manuals/VERSION.md)
- [npm 보러가기 ↗](https://www.npmjs.com/package/iamport-cordova)
